@@ -71,7 +71,6 @@
 #'
 #' # use all the get_ functions above to create a named list with tibbles
 #' kyy_db <- get_database(subdomain)
-#'
 #' }
 #'
 #' @references
@@ -83,7 +82,7 @@
 #' \item Ministry of Rural Development and Food.
 #' \item National Meteorological Service.
 #' \item Greek Public Power Corporation.
-#'}
+#' }
 #'
 #' European Terrestrial Reference System 1989 (ETRS),
 #' \url{http://bit.ly/2kJwFuf}
@@ -97,77 +96,78 @@ NULL
 
 #' @rdname get_tables
 #' @export get_stations
-get_stations <- function(subdomain =  c("kyy", "ypaat", "emy", "deh"),
+get_stations <- function(subdomain = c("kyy", "ypaat", "emy", "deh"),
                          translit = TRUE) {
-
   api <- "stations"
   enhydris_get(subdomain = subdomain, api_value = api, translit = translit)
-
 }
 
 #' @rdname get_tables
 #' @export get_timeseries
-get_timeseries <- function(subdomain =  c("kyy", "ypaat", "emy", "deh"),
-                           translit = TRUE){
+get_timeseries <- function(subdomain = c("kyy", "ypaat", "emy", "deh"),
+                           translit = TRUE) {
   api <- "timeseries"
   enhydris_get(subdomain = subdomain, api_value = api, translit = translit)
-
 }
 
 #' @rdname get_tables
 #' @export get_instruments
-get_instruments <- function(subdomain =  c("kyy", "ypaat", "emy", "deh"),
-                            translit = TRUE){
+get_instruments <- function(subdomain = c("kyy", "ypaat", "emy", "deh"),
+                            translit = TRUE) {
   api <- "instruments"
   enhydris_get(subdomain = subdomain, api_value = api, translit = translit)
 }
 
 #' @rdname get_tables
 #' @export get_water_basins
-get_water_basins <- function(subdomain =  c("kyy", "ypaat", "emy", "deh"),
-                            translit = TRUE){
+get_water_basins <- function(subdomain = c("kyy", "ypaat", "emy", "deh"),
+                             translit = TRUE) {
   api <- "water_basin"
   enhydris_get(subdomain = subdomain, api_value = api, translit = translit)
 }
 
 #' @rdname get_tables
 #' @export get_water_divisions
-get_water_divisions <- function(subdomain =  c("kyy", "ypaat", "emy", "deh"),
-                            translit = TRUE){
+get_water_divisions <- function(subdomain = c("kyy", "ypaat", "emy", "deh"),
+                                translit = TRUE) {
   api <- "water_division"
   enhydris_get(subdomain = subdomain, api_value = api, translit = translit)
 }
 
 #' @rdname get_tables
 #' @export get_political_divisions
-get_political_divisions <- function(subdomain =  c("kyy", "ypaat", "emy",
-                                                   "deh"),
-                               translit = TRUE){
+get_political_divisions <- function(subdomain = c(
+                                      "kyy", "ypaat", "emy",
+                                      "deh"
+                                    ),
+                                    translit = TRUE) {
   api <- "political_division"
   enhydris_get(subdomain = subdomain, api_value = api, translit = translit)
 }
 
 #' @rdname get_tables
 #' @export get_variables
-get_variables <- function(subdomain =  c("kyy", "ypaat", "emy", "deh"),
-                                   translit = TRUE){
+get_variables <- function(subdomain = c("kyy", "ypaat", "emy", "deh"),
+                          translit = TRUE) {
   api <- "variable"
   enhydris_get(subdomain = subdomain, api_value = api, translit = translit)
 }
 
 #' @rdname get_tables
 #' @export get_units_of_measurement
-get_units_of_measurement <- function(subdomain =  c("kyy", "ypaat", "emy",
-                                                    "deh"),
-                         translit = TRUE){
+get_units_of_measurement <- function(subdomain = c(
+                                       "kyy", "ypaat", "emy",
+                                       "deh"
+                                     ),
+                                     translit = TRUE) {
   api <- "unit_of_measurement"
   enhydris_get(subdomain = subdomain, api_value = api, translit = translit)
 }
 
 #' @rdname get_tables
 #' @export get_time_steps
-get_time_steps <- function(subdomain =  c("kyy", "ypaat", "emy", "deh"),
-                                     translit = TRUE){
+get_time_steps <- function(subdomain = c("kyy", "ypaat", "emy", "deh"),
+                           translit = TRUE) {
   api <- "time_step"
   enhydris_get(subdomain = subdomain, api_value = api, translit = translit)
 }
@@ -175,8 +175,8 @@ get_time_steps <- function(subdomain =  c("kyy", "ypaat", "emy", "deh"),
 
 #' @rdname get_tables
 #' @export get_owners
-get_owners <- function(subdomain =  c("kyy", "ypaat", "emy", "deh"),
-                           translit = TRUE){
+get_owners <- function(subdomain = c("kyy", "ypaat", "emy", "deh"),
+                       translit = TRUE) {
   api <- "owner"
   enhydris_get(subdomain = subdomain, api_value = api, translit = translit)
 }
@@ -184,35 +184,36 @@ get_owners <- function(subdomain =  c("kyy", "ypaat", "emy", "deh"),
 
 #' @rdname get_tables
 #' @export get_instruments_type
-get_instruments_type <- function(subdomain =  c("kyy", "ypaat", "emy", "deh"),
-                       translit = TRUE){
+get_instruments_type <- function(subdomain = c("kyy", "ypaat", "emy", "deh"),
+                                 translit = TRUE) {
   api <- "instrument_type"
   enhydris_get(subdomain = subdomain, api_value = api, translit = translit)
 }
 
 #' @rdname get_tables
 #' @export get_station_type
-get_station_type <- function(subdomain =  c("kyy", "ypaat", "emy", "deh"),
-                                 translit = TRUE){
+get_station_type <- function(subdomain = c("kyy", "ypaat", "emy", "deh"),
+                             translit = TRUE) {
   api <- "station_type"
   enhydris_get(subdomain = subdomain, api_value = api, translit = translit)
 }
 
 #' @rdname get_tables
 #' @export get_database
-get_database <- function(subdomain =  c("kyy", "ypaat", "emy", "deh"),
+get_database <- function(subdomain = c("kyy", "ypaat", "emy", "deh"),
                          translit = TRUE) {
-
-  list("stations" = get_stations(subdomain, translit),
-       "timeseries" = get_timeseries(subdomain, translit),
-       "instruments" = get_instruments(subdomain, translit),
-       "water_basins" = get_water_basins(subdomain, translit),
-       "water_divisions" = get_water_divisions(subdomain, translit),
-       "political_divisions" = get_political_divisions(subdomain, translit),
-       "variables" = get_variables(subdomain, translit),
-       "units_of_measurement" = get_units_of_measurement(subdomain, translit),
-       "time_steps" = get_time_steps(subdomain, translit),
-       "owners" = get_owners(subdomain, translit),
-       "instruments_type" = get_instruments_type(subdomain, translit),
-       "stations_type" = get_station_type(subdomain, translit))
+  list(
+    "stations" = get_stations(subdomain, translit),
+    "timeseries" = get_timeseries(subdomain, translit),
+    "instruments" = get_instruments(subdomain, translit),
+    "water_basins" = get_water_basins(subdomain, translit),
+    "water_divisions" = get_water_divisions(subdomain, translit),
+    "political_divisions" = get_political_divisions(subdomain, translit),
+    "variables" = get_variables(subdomain, translit),
+    "units_of_measurement" = get_units_of_measurement(subdomain, translit),
+    "time_steps" = get_time_steps(subdomain, translit),
+    "owners" = get_owners(subdomain, translit),
+    "instruments_type" = get_instruments_type(subdomain, translit),
+    "stations_type" = get_station_type(subdomain, translit)
+  )
 }
